@@ -23,14 +23,22 @@ class Form(Form):
 
 
 class Container(Div):
-    style = {
-        'display': 'flex',
-        'flex-direction': 'column',
-        'align-items': 'center',
-        'max-width': '960px',
-        'width': '96vw',
-        'margin': 'auto',
-    }
+    sass = '''
+    .Container
+        display: flex
+        flex-direction: column
+        align-items: center
+        max-width: 960px
+        width: 96vw
+        margin: auto
+
+    .up-modal .Container
+        width: 86vw
+
+    @media screen and (max-width: 500px)
+        .up-modal .up-modal-content
+            padding: 10px
+    '''
 
 
 class FormContainer(Container):
@@ -39,12 +47,17 @@ class FormContainer(Container):
         max-width: 580px
         .mdc-text-field, .mdc-form-field, .mdc-select, form
             width: 100%
+            max-width: 90vw
     '''
 
 
 class PageMenu(Div):
     attrs = dict(cls='mdc-elevation--z2', style='margin-bottom: 10px')
 
+    def __init__(self, *args, _next=None, **kwargs):
+        super().__init__(*args, **kwargs)
+        self._next = _next
+
     def to_html(self, *content, **context):
         if 'page-menu' not in context:
             return super().to_html(*content, **context)
@@ -56,6 +69,11 @@ class PageMenu(Div):
             if v.urlname == context['view'].urlname:
                 continue
 
+            href = v.url
+            if self._next:
+                if '?' not in href:
+                    href += '?'
+                href += '&_next=' + self._next
             button = A(
                 MDCTextButton(
                     v.label.capitalize(),
@@ -66,7 +84,7 @@ class PageMenu(Div):
                         'color': getattr(v, 'color', 'inherit'),
                     },
                 ),
-                href=v.url,
+                href=href,
                 style='text-decoration: none',
             )
             if getattr(v, 'controller', None) == 'modal':
@@ -150,6 +168,91 @@ class Body(Body):
             up.log.enable()
 
 
+class SpinnerOverlay(Div):
+    sass = '''
+    .SpinnerOverlay
+        position: fixed
+        width: 100%
+        height: 100%
+        top: 0
+        left: 0
+        right: 0
+        bottom: 0
+        background-color: rgba(255, 255, 255, 0.66)
+        z-index: 20000
+        cursor: pointer
+        padding-top: 30vh
+
+        .loader
+            color: var(--mdc-theme-primary)
+            opacity: 50%
+            font-size: 90px
+            text-indent: -9999em
+            overflow: hidden
+            width: 1em
+            height: 1em
+            border-radius: 50%
+            margin: 72px auto
+            position: relative
+            -webkit-transform: translateZ(0)
+            -ms-transform: translateZ(0)
+            transform: translateZ(0)
+            -webkit-animation: load6 1.7s infinite ease, round 1.7s infinite ease
+            animation: load6 1.7s infinite ease, round 1.7s infinite ease
+
+        @-webkit-keyframes load6
+            0%
+                box-shadow: 0 -0.83em 0 -0.4em, 0 -0.83em 0 -0.42em, 0 -0.83em 0 -0.44em, 0 -0.83em 0 -0.46em, 0 -0.83em 0 -0.477em
+            5%, 95%
+                box-shadow: 0 -0.83em 0 -0.4em, 0 -0.83em 0 -0.42em, 0 -0.83em 0 -0.44em, 0 -0.83em 0 -0.46em, 0 -0.83em 0 -0.477em
+            10%, 59%
+                box-shadow: 0 -0.83em 0 -0.4em, -0.087em -0.825em 0 -0.42em, -0.173em -0.812em 0 -0.44em, -0.256em -0.789em 0 -0.46em, -0.297em -0.775em 0 -0.477em
+            20%
+                box-shadow: 0 -0.83em 0 -0.4em, -0.338em -0.758em 0 -0.42em, -0.555em -0.617em 0 -0.44em, -0.671em -0.488em 0 -0.46em, -0.749em -0.34em 0 -0.477em
+            38%
+                box-shadow: 0 -0.83em 0 -0.4em, -0.377em -0.74em 0 -0.42em, -0.645em -0.522em 0 -0.44em, -0.775em -0.297em 0 -0.46em, -0.82em -0.09em 0 -0.477em
+            100%
+                box-shadow: 0 -0.83em 0 -0.4em, 0 -0.83em 0 -0.42em, 0 -0.83em 0 -0.44em, 0 -0.83em 0 -0.46em, 0 -0.83em 0 -0.477em
+        @keyframes load6
+            0%
+                box-shadow: 0 -0.83em 0 -0.4em, 0 -0.83em 0 -0.42em, 0 -0.83em 0 -0.44em, 0 -0.83em 0 -0.46em, 0 -0.83em 0 -0.477em
+            5%, 95%
+                box-shadow: 0 -0.83em 0 -0.4em, 0 -0.83em 0 -0.42em, 0 -0.83em 0 -0.44em, 0 -0.83em 0 -0.46em, 0 -0.83em 0 -0.477em
+            10%, 59%
+                box-shadow: 0 -0.83em 0 -0.4em, -0.087em -0.825em 0 -0.42em, -0.173em -0.812em 0 -0.44em, -0.256em -0.789em 0 -0.46em, -0.297em -0.775em 0 -0.477em
+            20%
+                box-shadow: 0 -0.83em 0 -0.4em, -0.338em -0.758em 0 -0.42em, -0.555em -0.617em 0 -0.44em, -0.671em -0.488em 0 -0.46em, -0.749em -0.34em 0 -0.477em
+            38%
+                box-shadow: 0 -0.83em 0 -0.4em, -0.377em -0.74em 0 -0.42em, -0.645em -0.522em 0 -0.44em, -0.775em -0.297em 0 -0.46em, -0.82em -0.09em 0 -0.477em
+            100%
+                box-shadow: 0 -0.83em 0 -0.4em, 0 -0.83em 0 -0.42em, 0 -0.83em 0 -0.44em, 0 -0.83em 0 -0.46em, 0 -0.83em 0 -0.477em
+        @-webkit-keyframes round
+            0%
+                -webkit-transform: rotate(0deg)
+                transform: rotate(0deg)
+            100%
+                -webkit-transform: rotate(360deg)
+                transform: rotate(360deg)
+        @keyframes round
+            0%
+                -webkit-transform: rotate(0deg)
+                transform: rotate(0deg)
+            100%
+                -webkit-transform: rotate(360deg)
+                transform: rotate(360deg)
+    '''  # noqa
+
+    def py2js(self):
+        up.proxy.config.slowDelay = 25
+        up.compiler('.SpinnerOverlay', lambda element: [
+            up.on('up:proxy:slow', lambda: up.element.show(element)),
+            up.on('up:proxy:recover', lambda: up.element.hide(element)),
+        ])
+
+    def __init__(self):
+        super().__init__(Div('...', cls='loader'), style='display:none')
+
+
 class App(Html):
     body_class = Body
     scripts = [
@@ -161,14 +264,17 @@ class App(Html):
         'https://unpkg.com/unpoly@1.0.0/dist/unpoly.css',
         # 'https://unpkg.com/unpoly@2.0.0-rc9/unpoly.min.css',
     ]
+    sass = '''
+    .up-modal .up-modal-viewport
+        padding-left: 0
+        padding-right: 0
+        padding-top: 10px
+    '''
 
     def to_html(self, *content, **context):
-        self.head.content.append(
-            Style('.up-modal-content { padding-top: 0; padding-bottom: 0; }')
-        )
         if title := getattr(context['view'], 'title', None):
             self.head.content.append(Title(title))
-        return super().to_html(*content, **context)
+        return super().to_html(*content, SpinnerOverlay(), **context)
 
 
 class NarrowCard(Div):
@@ -244,7 +350,7 @@ class Swagger(Div):
         )
 
 
-@template('crudlfap/home.html', App)
+@template('crudlfap/home.html', App, Container)
 class Home(Div):
     def to_html(self, **context):
         site = Site.objects.get_current()
@@ -275,7 +381,7 @@ class LoggedOut(Div):
         )
 
 
-@template('crudlfap/detail.html', App, NarrowCard)
+@template('crudlfap/detail.html', App)
 class ObjectDetail(Div):
     def to_html(self, **context):
         table = MDCDataTable()
@@ -289,7 +395,7 @@ class ObjectDetail(Div):
                 MDCDataTableTd(field['value']),
             ))
 
-        return super().to_html(table, **context)
+        return super().to_html(PageMenu(), NarrowCard(table), **context)
 
     def context(self, *content, **context):
         context['page-menu'] = context['view'].router.get_menu(
@@ -381,7 +487,7 @@ class ObjectList(Div):
 
         return super().to_html(
             self.drawer_component(**context) or '',
-            PageMenu(),
+            PageMenu(_next=context['view'].request.path),
             Div(
                 self.search_component(**context) or '',
                 table,
@@ -753,17 +859,26 @@ class mdcTopAppBar(Header):
     def nav():
         window.drawer.open = not window.drawer.open
 
+    def close():
+        if window.visualViewport.width < 800:
+            window.drawer.open = False
+
     def py2js(self):
-        window.addEventListener('DOMContentLoaded', self.setup)
+        up.compiler('#drawer, #app-bar, #main', self.setup)
 
     def setup():
-        window.drawer = mdc.drawer.MDCDrawer.attachTo(
-            document.getElementById('drawer'))
-        topAppBar = mdc.topAppBar.MDCTopAppBar.attachTo(
-            document.getElementById('app-bar'))
-        topAppBar.setScrollTarget(document.getElementById('main'))
+        drawer = document.getElementById('drawer')
+        app_bar = document.getElementById('app-bar')
+        main = document.getElementById('main')
+
+        window.drawer = mdc.drawer.MDCDrawer.attachTo(drawer)
+        topAppBar = mdc.topAppBar.MDCTopAppBar.attachTo(app_bar)
+        topAppBar.setScrollTarget(main)
         topAppBar.listen('MDCTopAppBar:nav', self.nav)
 
+        for link in drawer.querySelectorAll('a'):
+            link.addEventListener('click', self.close)
+
 
 class mdcDrawer(Aside):
     menu_hooks = []
