@@ -1,6 +1,5 @@
 import json
 
-from django import http
 from django.contrib.admin.models import LogEntry
 from django.contrib.contenttypes.models import ContentType
 from django.forms import models as model_forms
@@ -42,12 +41,6 @@ class ModelFormMixin(ModelMixin, FormMixin):
     """ModelForm Mixin using readable"""
     menus = ['model']
 
-    def form_valid_json(self):
-        return http.JsonResponse({
-            'data': self.router.serialize(self.object),
-            'status': 'created',
-        }, status=201)
-
     def get_form_kwargs(self):
         self.form_kwargs = super().get_form_kwargs()
         if (
@@ -94,6 +87,20 @@ class ModelFormMixin(ModelMixin, FormMixin):
         ).capitalize()
 
     def message_html(self, message):
+        """Add the detail url for form.instance, if possible."""
+        if getattr(self, 'object', None):
+            try:
+                url = self.object.get_absolute_url()
+            except Exception:
+                return message
+
+            return ' '.join((
+                message,
+                '<a href="{}" class="btn-flat toast-action">{}</a>'.format(
+                    url,
+                    _('detail').capitalize(),
+                ),
+            ))
         return message
 
     def get_log_action_flag(self):
