@@ -1,9 +1,8 @@
-from crudlfap import crudlfap
-
+import pytest
 from django.contrib.auth.models import Group, Permission
 from django.urls import resolve, reverse
 
-import pytest
+from crudlfap import shortcuts as crudlfap
 
 from .crudlfap import User
 
@@ -81,16 +80,8 @@ def test_su_user_reverse():
     assert reverse('crudlfap:su') == '/su'
 
 
-def test_login_reverse():
-    assert reverse('crudlfap:login') == '/login'
-
-
-def test_logout_reverse():
-    assert reverse('crudlfap:logout') == '/logout'
-
-
 def test_url_reverse():
-    assert reverse('crudlfap:urls') == '/urls'
+    assert reverse('crudlfap:url:list') == '/url'
 
 
 @pytest.mark.django_db
@@ -123,18 +114,6 @@ def test_user_detail_resolve(user):
     assert result.func.view_class.urlname == 'detail'
 
 
-@pytest.mark.django_db
-def test_user_logout_resolve(user):
-    result = resolve('/logout')
-    assert result.func.view_class.urlname == 'logout'
-
-
-@pytest.mark.django_db
-def test_user_login_resolve():
-    result = resolve('/login')
-    assert result.func.view_class.urlname == 'login'
-
-
 def test_user_list_resolve():
     result = resolve('/user').func.view_class
     assert issubclass(result, crudlfap.ListView)
@@ -303,38 +282,12 @@ def test_group_delete(admin_client):
     assert result.status_code == 404
 
 
-@pytest.mark.django_db
-def test_user_login_get(admin_client):
-    result = admin_client.get('/login')
-    assert result.status_code == 302
-
-
-@pytest.mark.django_db
-def test_user_login_post(admin_client):
-    result = admin_client.post('/login', dict(
-        username='lol',
-        new_password1='123',
-    ))
-    assert result.status_code == 302
-    assert result['Location'] == '/'
-
-
-@pytest.mark.django_db
-def test_user_logout_get(admin_client):
-    result = admin_client.get('/logout')
-    assert result.status_code == 200
-
-
 def test_become_user(admin_client, admin_user, suuser, user):
     assert admin_client.session.get('become_user') is None
 
-    result = admin_client.get('/user/admin/su', follow=True)
-    assert result.status_code == 200
-    assert admin_client.session.get('become_user') == admin_user.id
-
     result = admin_client.get('/user/suuser/su', follow=True)
     assert result.status_code == 200
-    assert admin_client.session.get('become_user') == admin_user.id
+    assert admin_client.session.get('become_user') == str(admin_user.id)
 
     result = admin_client.get('/su', follow=True)
     assert result.status_code == 200
@@ -342,3 +295,4 @@ def test_become_user(admin_client, admin_user, suuser, user):
 
     result = admin_client.get('/user/foo/su', follow=True)
     assert result.status_code == 200
+    assert admin_client.session.get('become_user') == str(admin_user.id)
